function y = Bounded(C,varargin)
% BOUNDED Compute the indicator function of the real interval
% [vargargin{1}(1), varargin{1}(3)].
%
%  y = Bounded(C,varargin)
%
% It computes the indicator function of the real interval [a,b], where a =
% vargargin{1}(1) and b = = vargargin{1}(1). If the input is a matrix, the
% function is applied to its eigenvalues.
%
%--------------------------------------------------------------------------
% MANDATORY INPUT
%
% C        : (double array) argument of the indicatorfunction
%
%--------------------------------------------------------------------------
% OPTIONAL INPUT
%
% varargin : (double array) 2-dimensional array, the 1st element is the
%                           lower bound while the 2nd is the upper bound.
%                           Default: [0,1]
%
%
%--------------------------------------------------------------------------
% OUTPUT
%
% y        : (double) value of the indicator function
%
%==========================================================================
%
% Version : 1.0 (04-06-2019)
% Author  : A. Benfenati (alessandro.benfenati@unimi.it)
%
%==========================================================================
%
% COPYRIGHT NOTIFICATION
%
% Permission to copy and modify this software and its documentation for
% internal research use is granted, provided that this notice is retained
% thereon and on all copies or modifications. The authors and their
% respective Universities makes no representations as to the suitability
% and operability of this software for any purpose. It is provided "as is"
% without express or implied warranty. Use of this software for commercial
% purposes is expressly prohibited without contacting the authors.
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by the
% Free Software Foundation; either version 3 of the License, or (at your
% option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
% Public License for more details.
%
% You should have received a copy of the GNU General Public License along
% with this program; if not, either visite http://www.gnu.org/licenses/ or
% write to Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
% 02139, USA.
%

a = 0;
b = 1;

if ~isempty(varargin)
    if numel(varargin{1})~=2
        error('Dimension not consistent');
    end
    a = varargin{1}(1);
    b = varargin{1}(2);
end


if ~isvector(C)
    % Matrix case
    [~, C]  = eig(C);
    C       = diag(C);
    y = realmax * sum((C<a) | (C>b));
    y = exp(y)-1;
else
    % Vector case
    y = realmax * sum((C<a) | (C>b));
    y = exp(y)-1;
end
% Usaging realmax is justified by the employ of the exponential
% function.
