function y = Schatten2(C,varargin)
% SCHATTEN2 Compute the Schatten-1 norm of a  matrix.
%
%  y = Schatten2(C,varargin)
%
% It computes the Schatten-2 norm of its argument. If the vector of the
% eigenvalues is provided, then the Schatten-2 norm reduces to be just the
% sum of the squared elements.
%
%--------------------------------------------------------------------------
% MANDATORY INPUT
%
% C        : (double array) argument of the norm
%
%--------------------------------------------------------------------------
% OPTIONAL INPUT
%
% varargin : not implemented, just for consistency with the other m-files.
% 
%--------------------------------------------------------------------------
% OUTPUT
% 
% y        : (double) value of the norm
%
%==========================================================================
%
% Version : 1.0 (04-06-2019)
% Author  : A. Benfenati (alessandro.benfenati@unimi.it)
%
%==========================================================================
%
% COPYRIGHT NOTIFICATION
%
% Permission to copy and modify this software and its documentation for
% internal research use is granted, provided that this notice is retained
% thereon and on all copies or modifications. The authors and their
% respective Universities makes no representations as to the suitability
% and operability of this software for any purpose. It is provided "as is"
% without express or implied warranty. Use of this software for commercial
% purposes is expressly prohibited without contacting the authors.
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by the
% Free Software Foundation; either version 3 of the License, or (at your
% option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
% Public License for more details.
%
% You should have received a copy of the GNU General Public License along
% with this program; if not, either visite http://www.gnu.org/licenses/ or
% write to Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
% 02139, USA.
%

% Check dimensions: in case of a vector, the operation is simplified and
% more cheap.
if ismember(1,size(C))
    y = norm(C);
    y = y*y;
else
    y = norm(C,'fro');
    y = y*y;
end