clearvars
close all
clc

% Add the folders containing the m-files needed for the tests
addpath SideFuns/
addpath Funs/
addpath Solvers/
addpath Prox/
addpath Molene_Data/

% Load the wind dataset
load datawind2.mat

%% Choose which data use for the graph estimation:
%
% wind_intensity : double array (30 x 72) of wind intensity data
% wind_direction : double array (30 x 72) of wind direction data
% wind_driXint   : double array (30 x 72) of wind direction x intensity data
%
% The corresponding covariance matrices are
%
% S_direction : cov. matrix of wind direction data
% S_intensity : cov. matrix of wind intensity data
% S_driXint   : cov. matrix of wind direction x intensity data
%
% The corresponding noise values are
%
% sigma_direction : noise value for wind direction data
% sigma_intensity : noise value for wind intensity data
% Sigma_driXint   : noise value for wind direction x intensity data
%


S     = S_dirXint;
sigma = sigma_dirXint;
% S = (wind_direction).*wind_intensity;
D = D+D';
D = 0.1.^D;
% sigma = std(S(:));
S = D.*S;%cov(S');
% Starting point
J = S;
% Choose the method: GLASSO, MMDR or DR
method = 'MMDR';

if strcmp(method,'MMDR')
    optionsMMDR.mu0         = 1;
    optionsMMDR.mu0b        = 1;
    optionsMMDR.mu1         = 1e-1;
    optionsMMDR.gamma       = 10;       % Prox parameter
    optionsMMDR.INNITER     = 2000;      % number of iterations
    optionsMMDR.innstop     = 2;         % stopping criterion
    optionsMMDR.inntol      = 1e-5;      % tolerance for the criterion
    optionsMMDR.EXTITER     = 20;        % number of iterations
    optionsMMDR.extstop     = 2;         % stopping criterion
    optionsMMDR.exttol      = 1e-4;      % tolerance for the criterion
    optionsMMDR.lambda      = 1;
    optionsMMDR.F           = 'LogDet';
    optionsMMDR.g0          = 'iSchatten1';
    optionsMMDR.init        = J;
    optionsMMDR.params      = [optionsMMDR.mu0, sigma];
    
    [C_fin, Cn, fobjG, Q, t_vecG, RMSEC] = MMDR(optionsMMDR.init,...
        optionsMMDR.gamma, optionsMMDR.mu0, optionsMMDR.mu1, S, sigma, ...
        'INNITER', optionsMMDR.INNITER,...
        'INNSTOP', optionsMMDR.innstop,...
        'INNTOL',  optionsMMDR.inntol,...
        'EXTITER', optionsMMDR.EXTITER,...
        'EXTSTOP', optionsMMDR.extstop,...
        'EXTTOL',  optionsMMDR.exttol,...
        'LAMBDA',  optionsMMDR.lambda,...
        'F',       optionsMMDR.F,...
        'G0',      optionsMMDR.g0,...
        'verbose', 1,...
        'PARAMS',  optionsMMDR.params);
    
    
    
elseif strcmp(method,'GLASSO')
    
    optionsGLASSO.mu1       = 5e-6;
    optionsGLASSO.alpha     = 1.8;
    optionsGLASSO.rho       = 4;
    optionsGLASSO.iter      = 40000;
    optionsGLASSO.reltol    = 1e-6;
    optionsGLASSO.abstol    = 1e-6;
    
    
    [C_fin, history] = covsel(S, optionsGLASSO.mu1, optionsGLASSO.rho, optionsGLASSO.alpha,...
        'ITER',optionsGLASSO.iter,...
        'RELTOL',optionsGLASSO.reltol,...
        'ABSTOL',optionsGLASSO.abstol);
    
    
    
elseif strcmp(method,'DR')
    J = S + 0.01*eye(size(S));
    
    
    optionsDR.mu0         = 1e-3;
    optionsDR.mu1         = 6e-5;
    optionsDR.gamma       = 1;       % Prox parameter
    optionsDR.INNITER     = 3000;      % number of iterations
    optionsDR.innstop     = 2;         % stopping criterion
    optionsDR.inntol      = 1e-8;      % tolerance for the criterion
    optionsDR.lambda      = 1;
    optionsDR.F           = 'LogDet';
    optionsDR.g0          = 'iSchatten1';
    optionsDR.init        = J;
    optionsDR.params      = [optionsDR.mu0];
    
    
    [C_fin, ~,fobjDR, t_vecDR] = DR_matrix(optionsDR.init,...
        optionsDR.gamma, optionsDR.mu0, optionsDR.mu1, S,...
        'ITER',    optionsDR.INNITER,...
        'STOP',    optionsDR.innstop,...
        'TOL',     optionsDR.inntol,...
        'LAMBDA',  optionsDR.lambda,...
        'F',       optionsDR.F,...
        'G0',      optionsDR.g0,...
        'VERBOSE', 1,...
        'PARAMS',  optionsDR.params);
    
    
    
else
    error('Unknown method.')
end

ShowGraphOnMap
%==========================================================================
%
% Version : 1.0 (22-10-2019)
% Author  : A. Benfenati (alessandro.benfenati@unimi.it)
%
%==========================================================================
%
% COPYRIGHT NOTIFICATION
%
% Permission to copy and modify this software and its documentation for
% internal research use is granted, provided that this notice is retained
% thereon and on all copies or modifications. The authors and their
% respective Universities makes no representations as to the suitability
% and operability of this software for any purpose. It is provided "as is"
% without express or implied warranty. Use of this software for commercial
% purposes is expressly prohibited without contacting the authors.
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by the
% Free Software Foundation; either version 3 of the License, or (at your
% option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
% Public License for more details.
%
% You should have received a copy of the GNU General Public License along
% with this program; if not, either visite http://www.gnu.org/licenses/ or
% write to Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
% 02139, USA.